@@ -5,7 +5,7 @@ pub mod test {
     #[test]
     fn test_get_all() {
         let list = get_all(None);
-        assert_eq!(list.len(), 251);
+        assert_eq!(list.len(), 386);
     }
     #[test]
     fn test_non_english_get_all_pokemon_get_bulbasaur() {
@@ -57,10 +57,39 @@ pub mod test {
         let typlosion = get_by_id(157, Some("ru"));
         assert_eq!(typlosion, "Тайфложн");
     }
+    #[test]
+    fn test_gen_3_support_english() {
+        let deoxys = get_by_id(386, None);
+        assert_eq!(deoxys, "Deoxys");
+    }
+    #[test]
+    fn test_gen_3_support_chinese() {
+        let rayquaza = get_by_id(384, Some("ch"));
+        assert_eq!(rayquaza, "烈空坐");
+    }
+    #[test]
+    fn test_gen_3_support_german() {
+        let marshtomp = get_by_id(259, Some("de"));
+        assert_eq!(marshtomp, "Moorabbel");
+    }
+    #[test]
+    fn test_gen_3_support_french() {
+        let jirachi = get_by_id(385, Some("fr"));
+        assert_eq!(jirachi, "Jirachi");
+    }
+    #[test]
+    fn test_gen_3_support_japanese() {
+        let latias = get_by_id(380, Some("jp"));
+        assert_eq!(latias, "ラティアス");
+    }
+    #[test]
+    fn test_gen_3_support_russian() {
+        let regigas = get_by_id(379, Some("ru"));
+        assert_eq!(regigas, "Реджистил");
+    }
     #[cfg(test)]
     mod panic_tests {
         use crate::{get_all, get_by_id, get_id_by_name, random};
-
         #[test]
         #[should_panic]
         fn get_all_should_panic_when_non_supported_language_is_given() {
